@@ -42,14 +42,18 @@ options:
 """
 import os
 import sys
+import json
 from docopt import docopt
 from textwrap import dedent
+from typing import Dict
+
 from cloud_builder.version import __version__
 from cloud_builder.cloud_logger import CBCloudLogger
 from cloud_builder.broker import CBMessageBroker
 from cloud_builder.response.response import CBResponse
 from cloud_builder.exceptions import exception_handler
 from cloud_builder.defaults import Defaults
+
 from kiwi.command import Command
 from kiwi.utils.sync import DataSync
 from kiwi.privileges import Privileges
@@ -87,59 +91,32 @@ def main() -> None:
     status_flags = Defaults.get_status_flags()
 
     dist_profile = args['--profile']
+    build_root = args['--root']
     package_name = os.path.basename(args['--package'])
 
-    if args['--local']:
-        # In local (not on runner) mode we take the given package
-        # path to construct the target_root for building the package
-        target_root = ''.join(
-            [args['--package'], f'@{dist_profile}']
-        )
-    else:
-        # In non local (runner mode) the target root is constructed
-        # to point to the given base root directory
-        target_root = os.path.join(
-            args["--root"],
-            Defaults.get_projects_path(args['--package']),
-            f'{package_name}@{dist_profile}'
-        )
-
     # Solve buildroot packages and create solver json
-    prepare_log_file = f'{target_root}.prepare.log'
+    prepare_log_file = f'{build_root}.prepare.log'
     if not args['--local']:
-        solver_json_file = f'{target_root}.solver.json'
+        solver_json_file = f'{build_root}.solver.json'
         log.info(
             'Solving buildroot package list for {0}. Details in: {1}'.format(
-                target_root, solver_json_file
+                build_root, solver_json_file
             )
         )
-        Path.wipe(prepare_log_file)
-        kiwi_solve = Command.run(
-            [
-                Path.which(
-                    'kiwi-ng', alternative_lookup_paths=['/usr/local/bin']
-                ),
-                '--logfile', prepare_log_file,
-                '--profile', dist_profile,
-                'image', 'info',
-                '--description', args['--package'],
-                '--resolve-package-list'
-            ], raise_on_error=False
+        solver_result = resolve_build_dependencies(
+            args['--package'], dist_profile, prepare_log_file
         )
-        if kiwi_solve.output:
-            with open(solver_json_file, 'w') as solve_log:
-                process_line = False
-                for line in kiwi_solve.output.split(os.linesep):
-                    if line.startswith('{'):
-                        process_line = True
-                    if process_line:
-                        solve_log.write(line)
-                        solve_log.write(os.linesep)
+        with open(solver_json_file, 'w') as solve_result:
+            solve_result.write(
+                json.dumps(
+                    solver_result['solver_data'], sort_keys=True, indent=4
+                )
+            )
 
     # Install buildroot
     log.info(
         'Creating buildroot {0}. Details in: {1}'.format(
-            target_root, prepare_log_file
+            build_root, prepare_log_file
         )
     )
     kiwi_run_caller_options = [
@@ -159,7 +136,7 @@ def main() -> None:
             'system', 'prepare',
             '--description', args['--package'],
             '--allow-existing-root',
-            '--root', target_root
+            '--root', build_root
         ]
     )
     exit_code = os.WEXITSTATUS(
@@ -174,7 +151,7 @@ def main() -> None:
         try:
             data = DataSync(
                 f'{args["--package"]}/',
-                f'{target_root}/{package_name}/'
+                f'{build_root}/{package_name}/'
             )
             data.sync_data(
                 options=['-a', '-x']
@@ -198,7 +175,7 @@ def main() -> None:
                 pushd {0}
                 build --no-init --root /
             ''')
-            with open(f'{target_root}/run.sh', 'w') as script:
+            with open(f'{build_root}/run.sh', 'w') as script:
                 script.write(
                     run_script.format(package_name)
                 )
@@ -218,7 +195,7 @@ def main() -> None:
             package=package_name,
             log_file=prepare_log_file,
             solver_file=solver_json_file,
-            build_root=target_root,
+            build_root=build_root,
             exit_code=exit_code
         )
         broker = CBMessageBroker.new(
@@ -227,3 +204,66 @@ def main() -> None:
         log.response(response, broker)
 
     sys.exit(exit_code)
+
+
+def resolve_build_dependencies(
+    package_source_path: str, dist_profile: str, log_file: str = ''
+) -> Dict:
+    """
+    Resolve build dependencies
+
+    :return:
+        Returns a dictionary containing result and potential
+        issue information like in the following example
+
+        .. code:: python
+
+            {
+                'solver_data': dict,
+                'solver_log': 'log_data'
+            }
+
+    :rtype: Dict
+    """
+    solver_result = {
+        'solver_data': {},
+        'solver_log': ''
+    }
+    kiwi_solve = Command.run(
+        [
+            Path.which(
+                'kiwi-ng', alternative_lookup_paths=['/usr/local/bin']
+            ),
+            '--profile', dist_profile,
+            'image', 'info',
+            '--description', package_source_path,
+            '--resolve-package-list'
+        ], raise_on_error=False
+    )
+    log_data = ''
+    solver_data = ''
+    if kiwi_solve.output:
+        solver_line = False
+        for line in kiwi_solve.output.split(os.linesep):
+            if line.startswith('{'):
+                solver_line = True
+            if solver_line:
+                solver_data += line
+            else:
+                log_data = ''.join(
+                    [log_data, line, os.linesep]
+                )
+
+    if kiwi_solve.error:
+        log_data += kiwi_solve.error
+
+    if solver_data:
+        solver_result['solver_data'] = json.loads(solver_data)
+    if log_data:
+        solver_result['solver_log'] = log_data
+
+    if log_file:
+        with open(log_file, 'w') as log_fd:
+            log_fd.write(format(solver_result['solver_log']))
+
+    return solver_result
